summaryrefslogtreecommitdiffstats
path: root/app
diff options
context:
space:
mode:
authorJean-Philippe Lang <jp_lang@yahoo.fr>2010-09-26 08:16:05 +0000
committerJean-Philippe Lang <jp_lang@yahoo.fr>2010-09-26 08:16:05 +0000
commita7fd592db4037d635d04ca5ce3f01d0af3f0c8ae (patch)
treed4ab8ec1807ecdcd8f2509681def9cd2dd7e218a /app
parente9686cbbe57a671468588638ddc3d6a923400694 (diff)
downloadredmine-a7fd592db4037d635d04ca5ce3f01d0af3f0c8ae.tar.gz
redmine-a7fd592db4037d635d04ca5ce3f01d0af3f0c8ae.zip
Fixed: gantt broken when no due date on project issues and versions.
git-svn-id: svn+ssh://rubyforge.org/var/svn/redmine/trunk@4178 e93f8b46-1217-0410-a6f0-8f06a7374b81
Diffstat (limited to 'app')
-rw-r--r--app/models/project.rb5
1 files changed, 3 insertions, 2 deletions
diff --git a/app/models/project.rb b/app/models/project.rb
index 4b0236b37..29be68c70 100644
--- a/app/models/project.rb
+++ b/app/models/project.rb
@@ -432,13 +432,14 @@ class Project < ActiveRecord::Base
end
end
# The latest due date of an issue or version
def due_date
if module_enabled?(:issue_tracking)
[
issues.maximum('due_date'),
shared_versions.collect(&:effective_date),
- shared_versions.collect {|v| v.fixed_issues.maximum('due_date')}
+ shared_versions.collect {|v| v.fixed_issues.maximum('due_date')},
+ Date.today
].flatten.compact.max
end
end
@@ -432,13 +432,14 @@ class Project < ActiveRecord::Base
end
end
- # The latest due date of an issue or version
+ # The latest due date of an issue or version, otherwise today
def due_date
if module_enabled?(:issue_tracking)